==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-incident-mgmt-itil/dictionaries/pt_br.dict.itop-incident-mgmt-itil.php <==
<?php
// Copyright (C) 2010-2023 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/**
 * Localized data
 *
 * @copyright   Copyright (C) 2010-2023 Combodo SARL
 * @license     http://opensource.org/licenses/AGPL-3.0
 */
Dict::Add('PT BR', 'Brazilian', 'Brazilian', array(
	'Menu:IncidentManagement' => 'Gerenciamento de Incidentes',
	'Menu:IncidentManagement+' => '',
	'Menu:Incident:Overview' => 'Visão geral',
	'Menu:Incident:Overview+' => '',
	'Menu:NewIncident' => 'Novo incidente',
	'Menu:NewIncident+' => 'Criar um novo incidente',
	'Menu:SearchIncidents' => 'Pesquisar por incidentes',
	'Menu:SearchIncidents+' => 'Pesquisar por solicitações de incidentes',
	'Menu:Incident:Shortcuts' => 'Atalhos',
	'Menu:Incident:Shortcuts+' => '',
	'Menu:Incident:MyIncidents' => 'Incidentes atribuídos para mim',
	'Menu:Incident:MyIncidents+' => 'Incidentes atribuídos para mim (como Agente)',
	'Menu:Incident:EscalatedIncidents' => 'Incidentes escalonados',
	'Menu:Incident:EscalatedIncidents+' => '',
	'Menu:Incident:OpenIncidents' => 'Todos os incidentes abertos',
	'Menu:Incident:OpenIncidents+' => '',
	'UI-IncidentManagementOverview-IncidentByPriority-last-14-days' => 'Incidentes dos últimos 14 dias por prioridade',
	'UI-IncidentManagementOverview-Last-14-days' => 'Incidentes dos últimos 14 dias por prioridade',
	'UI-IncidentManagementOverview-OpenIncidentByStatus' => 'Incidentes abertos por status',
	'UI-IncidentManagementOverview-OpenIncidentByAgent' => 'Incidentes abertos por agente',
	'UI-IncidentManagementOverview-OpenIncidentByCustomer' => 'Incidentes abertos por cliente',
));


// Dictionnay conventions
// Class:<class_name>
// Class:<class_name>+
// Class:<class_name>/Attribute:<attribute_code>
// Class:<class_name>/Attribute:<attribute_code>+
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>+
// Class:<class_name>/Stimulus:<stimulus_code>
// Class:<class_name>/Stimulus:<stimulus_code>+

//
// Class: Incident
//

Dict::Add('PT BR', 'Brazilian', 'Brazilian', array(
	'Class:Incident' => 'Incidente',
	'Class:Incident+' => '',
	'Class:Incident/Attribute:status' => 'Status',
	'Class:Incident/Attribute:status+' => '',
	'Class:Incident/Attribute:status/Value:new' => 'Novo',
	'Class:Incident/Attribute:status/Value:new+' => '',
	'Class:Incident/Attribute:status/Value:escalated_tto' => 'TTO escalonado',
	'Class:Incident/Attribute:status/Value:escalated_tto+' => '',
	'Class:Incident/Attribute:status/Value:assigned' => 'Atribuído',
	'Class:Incident/Attribute:status/Value:assigned+' => '',
	'Class:Incident/Attribute:status/Value:escalated_ttr' => 'TTR escalonado',
	'Class:Incident/Attribute:status/Value:escalated_ttr+' => '',
	'Class:Incident/Attribute:status/Value:waiting_for_approval' => 'Aguardando aprovação',
	'Class:Incident/Attribute:status/Value:waiting_for_approval+' => '',
	'Class:Incident/Attribute:status/Value:pending' => 'Pendente',
	'Class:Incident/Attribute:status/Value:pending+' => '',
	'Class:Incident/Attribute:status/Value:resolved' => 'Solucionado',
	'Class:Incident/Attribute:status/Value:resolved+' => '',
	'Class:Incident/Attribute:status/Value:closed' => 'Fechado',
	'Class:Incident/Attribute:status/Value:closed+' => '',
	'Class:Incident/Attribute:impact' => 'Impacto',
	'Class:Incident/Attribute:impact+' => '',
	'Class:Incident/Attribute:impact/Value:1' => 'Um departamento',
	'Class:Incident/Attribute:impact/Value:1+' => '',
	'Class:Incident/Attribute:impact/Value:2' => 'Um serviço',
	'Class:Incident/Attribute:impact/Value:2+' => '',
	'Class:Incident/Attribute:impact/Value:3' => 'Uma pessoa',
	'Class:Incident/Attribute:impact/Value:3+' => '',
	'Class:Incident/Attribute:priority' => 'Prioridade',
	'Class:Incident/Attribute:priority+' => '',
	'Class:Incident/Attribute:priority/Value:1' => 'Crítica',
	'Class:Incident/Attribute:priority/Value:1+' => '',
	'Class:Incident/Attribute:priority/Value:2' => 'Alta',
	'Class:Incident/Attribute:priority/Value:2+' => '',
	'Class:Incident/Attribute:priority/Value:3' => 'Média',
	'Class:Incident/Attribute:priority/Value:3+' => '',
	'Class:Incident/Attribute:priority/Value:4' => 'Baixa',
	'Class:Incident/Attribute:priority/Value:4+' => '',
	'Class:Incident/Attribute:urgency' => 'Urgência',
	'Class:Incident/Attribute:urgency+' => '',
	'Class:Incident/Attribute:urgency/Value:1' => 'Crítica',
	'Class:Incident/Attribute:urgency/Value:1+' => '',
	'Class:Incident/Attribute:urgency/Value:2' => 'Alta',
	'Class:Incident/Attribute:urgency/Value:2+' => '',
	'Class:Incident/Attribute:urgency/Value:3' => 'Média',
	'Class:Incident/Attribute:urgency/Value:3+' => '',
	'Class:Incident/Attribute:urgency/Value:4' => 'Baixa',
	'Class:Incident/Attribute:urgency/Value:4+' => '',
	'Class:Incident/Attribute:origin' => 'Origem',
	'Class:Incident/Attribute:origin+' => '',
	'Class:Incident/Attribute:origin/Value:in_person' => 'In-person~~',
	'Class:Incident/Attribute:origin/Value:in_person+' => 'Incident created following a face-to-face discussion~~',
	'Class:Incident/Attribute:origin/Value:chat' => 'Chat~~',
	'Class:Incident/Attribute:origin/Value:chat+' => 'Incident created following a ~~',
	'Class:Incident/Attribute:origin/Value:mail' => 'E-mail',
	'Class:Incident/Attribute:origin/Value:mail+' => '',
	'Class:Incident/Attribute:origin/Value:monitoring' => 'Monitoramento',
	'Class:Incident/Attribute:origin/Value:monitoring+' => '',
	'Class:Incident/Attribute:origin/Value:phone' => 'Telefone',
	'Class:Incident/Attribute:origin/Value:phone+' => '',
	'Class:Incident/Attribute:origin/Value:portal' => 'Portal do usuário',
	'Class:Incident/Attribute:origin/Value:portal+' => '',
	'Class:Incident/Attribute:service_id' => 'Serviço',
	'Class:Incident/Attribute:service_id+' => '',
	'Class:Incident/Attribute:service_name' => 'Nome do serviço',
	'Class:Incident/Attribute:service_name+' => '',
	'Class:Incident/Attribute:servicesubcategory_id' => 'Subcategoria do serviço',
	'Class:Incident/Attribute:servicesubcategory_id+' => '',
	'Class:Incident/Attribute:servicesubcategory_name' => 'Nome da subcategoria do serviço',
	'Class:Incident/Attribute:servicesubcategory_name+' => '',
	'Class:Incident/Attribute:escalation_flag' => 'Flag de escalonamento',
	'Class:Incident/Attribute:escalation_flag+' => '',
	'Class:Incident/Attribute:escalation_flag/Value:no' => 'Não',
	'Class:Incident/Attribute:escalation_flag/Value:no+' => '',
	'Class:Incident/Attribute:escalation_flag/Value:yes' => 'Sim',
	'Class:Incident/Attribute:escalation_flag/Value:yes+' => '',
	'Class:Incident/Attribute:escalation_reason' => 'Motivo do escalonamento',
	'Class:Incident/Attribute:escalation_reason+' => '',
	'Class:Incident/Attribute:assignment_date' => 'Data de atribuição',
	'Class:Incident/Attribute:assignment_date+' => '',
	'Class:Incident/Attribute:resolution_date' => 'Data de solução',
	'Class:Incident/Attribute:resolution_date+' => '',
	'Class:Incident/Attribute:last_pending_date' => 'Última data pendente',
	'Class:Incident/Attribute:last_pending_date+' => '',
	'Class:Incident/Attribute:cumulatedpending' => 'Pendências acumuladas',
	'Class:Incident/Attribute:cumulatedpending+' => '',
	'Class:Incident/Attribute:tto' => 'TTO',
	'Class:Incident/Attribute:tto+' => 'Tempo para atribuição',
	'Class:Incident/Attribute:ttr' => 'TTR',
	'Class:Incident/Attribute:ttr+' => 'Tempo para solução',
	'Class:Incident/Attribute:tto_escalation_deadline' => 'Prazo determinado de atribuição (TTO)',
	'Class:Incident/Attribute:tto_escalation_deadline+' => 'Prazo determinado de Tempo para atribuição (TTO)',
	'Class:Incident/Attribute:sla_tto_passed' => 'SLA TTO superado',
	'Class:Incident/Attribute:sla_tto_passed+' => 'Tempo para atribuição (TTO) do Acordo de Nível de Serviço (SLA) superado',
	'Class:Incident/Attribute:sla_tto_over' => 'SLA TTO ultrapassado',
	'Class:Incident/Attribute:sla_tto_over+' => 'Tempo para atribuição (TTO) do Acordo de Nível de Serviço (SLA) ultrapassado',
	'Class:Incident/Attribute:ttr_escalation_deadline' => 'Prazo determinado de solução (TTR)',
	'Class:Incident/Attribute:ttr_escalation_deadline+' => 'Prazo determinado de Tempo para solução (TTR)',
	'Class:Incident/Attribute:sla_ttr_passed' => 'SLA TTR superado',
	'Class:Incident/Attribute:sla_ttr_passed+' => 'Tempo para solução (TTR) do Acordo de Nível de Serviço (SLA) superado',
	'Class:Incident/Attribute:sla_ttr_over' => 'SLA TTR ultrapassado',
	'Class:Incident/Attribute:sla_ttr_over+' => 'Tempo para solução (TTR) do Acordo de Nível de Serviço (SLA) ultrapassado',
	'Class:Incident/Attribute:time_spent' => 'Tempo de solução',
	'Class:Incident/Attribute:time_spent+' => '',
	'Class:Incident/Attribute:resolution_code' => 'Código da solução',
	'Class:Incident/Attribute:resolution_code+' => '',
	'Class:Incident/Attribute:resolution_code/Value:assistance' => 'Assistência',
	'Class:Incident/Attribute:resolution_code/Value:assistance+' => '',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed' => 'Correção de bug',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed+' => '',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair' => 'Reparação de hardware',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair+' => '',
	'Class:Incident/Attribute:resolution_code/Value:other' => 'Outro',
	'Class:Incident/Attribute:resolution_code/Value:other+' => '',
	'Class:Incident/Attribute:resolution_code/Value:software patch' => 'Atualização de software',
	'Class:Incident/Attribute:resolution_code/Value:software patch+' => '',
	'Class:Incident/Attribute:resolution_code/Value:system update' => 'Atualização de sistema',
	'Class:Incident/Attribute:resolution_code/Value:system update+' => '',
	'Class:Incident/Attribute:resolution_code/Value:training' => 'Treinamento',
	'Class:Incident/Attribute:resolution_code/Value:training+' => '',
	'Class:Incident/Attribute:solution' => 'Solução',
	'Class:Incident/Attribute:solution+' => '',
	'Class:Incident/Attribute:pending_reason' => 'Motivo da pendência',
	'Class:Incident/Attribute:pending_reason+' => '',
	'Class:Incident/Attribute:parent_incident_id' => 'Incidente pai',
	'Class:Incident/Attribute:parent_incident_id+' => '',
	'Class:Incident/Attribute:parent_incident_ref' => 'Ref. Incidente pai',
	'Class:Incident/Attribute:parent_incident_ref+' => '',
	'Class:Incident/Attribute:parent_change_id' => 'Mudança pai',
	'Class:Incident/Attribute:parent_change_id+' => '',
	'Class:Incident/Attribute:parent_change_ref' => 'Ref. Mudança pai',
	'Class:Incident/Attribute:parent_change_ref+' => '',
	'Class:Incident/Attribute:parent_problem_id' => 'Problema pai',
	'Class:Incident/Attribute:parent_problem_id+' => '',
	'Class:Incident/Attribute:parent_problem_ref' => 'Ref. Problema pai',
	'Class:Incident/Attribute:parent_problem_ref+' => '',
	'Class:Incident/Attribute:related_request_list' => 'Solicitações filhas',
	'Class:Incident/Attribute:related_request_list+' => '',
	'Class:Incident/Attribute:child_incidents_list' => 'Incidentes filhos',
	'Class:Incident/Attribute:child_incidents_list+' => 'Todos os subincidentes associados a este incidente',
	'Class:Incident/Attribute:public_log' => 'Log público',
	'Class:Incident/Attribute:public_log+' => '',
	'Class:Incident/Attribute:user_satisfaction' => 'Satisfação do usuário',
	'Class:Incident/Attribute:user_satisfaction+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:1' => 'Muito satisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:1+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:2' => 'Satisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:2+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:3' => 'Insatisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:3+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:4' => 'Muito insatisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:4+' => '',
	'Class:Incident/Attribute:user_comment' => 'Comentário do usuário',
	'Class:Incident/Attribute:user_comment+' => '',
	'Class:Incident/Attribute:parent_incident_id_friendlyname' => 'parent_incident_id_friendlyname',
	'Class:Incident/Attribute:parent_incident_id_friendlyname+' => '',
	'Class:Incident/Stimulus:ev_assign' => 'Atribuir',
	'Class:Incident/Stimulus:ev_assign+' => '',
	'Class:Incident/Stimulus:ev_reassign' => 'Reatribuir',
	'Class:Incident/Stimulus:ev_reassign+' => '',
	'Class:Incident/Stimulus:ev_pending' => 'Pendente',
	'Class:Incident/Stimulus:ev_pending+' => '',
	'Class:Incident/Stimulus:ev_timeout' => 'Timeout',
	'Class:Incident/Stimulus:ev_timeout+' => '',
	'Class:Incident/Stimulus:ev_autoresolve' => 'Solucionado automaticamente',
	'Class:Incident/Stimulus:ev_autoresolve+' => '',
	'Class:Incident/Stimulus:ev_autoclose' => 'Fechado automaticamente',
	'Class:Incident/Stimulus:ev_autoclose+' => '',
	'Class:Incident/Stimulus:ev_resolve' => 'Marcar como solucionado',
	'Class:Incident/Stimulus:ev_resolve+' => '',
	'Class:Incident/Stimulus:ev_close' => 'Fechar esta solicitação',
	'Class:Incident/Stimulus:ev_close+' => '',
	'Class:Incident/Stimulus:ev_reopen' => 'Re-abrir',
	'Class:Incident/Stimulus:ev_reopen+' => '',
	'Class:Incident/Error:CannotAssignParentIncidentIdToSelf' => 'Não é possível atribuir o incidente pai ao próprio incidente',
	'Class:Incident/Method:ResolveChildTickets' => 'ResolveChildTickets (resolver solicitações filhas)',
	'Class:Incident/Method:ResolveChildTickets+' => 'Conecte a solução a solicitação filha (ev_autoresolve) e alinhe as seguintes características: serviço, equipe, agente, informação da solução',
	'Tickets:Related:OpenIncidents' => 'Incidentes abertos',
));

==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-incident-mgmt-itil/dictionaries/pt_br.dict.itop-incident-mgmt-itil.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('PT BR', 'Brazilian', 'Brazilian', [
	'Class:Incident' => 'Incidente',
	'Class:Incident+' => '',
	'Class:Incident/Attribute:assignment_date' => 'Data de atribuição',
	'Class:Incident/Attribute:assignment_date+' => '',
	'Class:Incident/Attribute:child_incidents_list' => 'Incidentes filhos',
	'Class:Incident/Attribute:child_incidents_list+' => 'Todos os subincidentes associados a este incidente',
	'Class:Incident/Attribute:cumulatedpending' => 'Pendências acumuladas',
	'Class:Incident/Attribute:cumulatedpending+' => '',
	'Class:Incident/Attribute:escalation_flag' => 'Flag de escalonamento',
	'Class:Incident/Attribute:escalation_flag+' => '',
	'Class:Incident/Attribute:escalation_flag/Value:no' => 'Não',
	'Class:Incident/Attribute:escalation_flag/Value:no+' => '',
	'Class:Incident/Attribute:escalation_flag/Value:yes' => 'Sim',
	'Class:Incident/Attribute:escalation_flag/Value:yes+' => '',
	'Class:Incident/Attribute:escalation_reason' => 'Motivo do escalonamento',
	'Class:Incident/Attribute:escalation_reason+' => '',
	'Class:Incident/Attribute:impact' => 'Impacto',
	'Class:Incident/Attribute:impact+' => '',
	'Class:Incident/Attribute:impact/Value:1' => 'Um departamento',
	'Class:Incident/Attribute:impact/Value:1+' => '',
	'Class:Incident/Attribute:impact/Value:2' => 'Um serviço',
	'Class:Incident/Attribute:impact/Value:2+' => '',
	'Class:Incident/Attribute:impact/Value:3' => 'Uma pessoa',
	'Class:Incident/Attribute:impact/Value:3+' => '',
	'Class:Incident/Attribute:last_pending_date' => 'Última data pendente',
	'Class:Incident/Attribute:last_pending_date+' => '',
	'Class:Incident/Attribute:origin' => 'Origem',
	'Class:Incident/Attribute:origin+' => '',
	'Class:Incident/Attribute:origin/Value:chat' => 'Chat~~',
	'Class:Incident/Attribute:origin/Value:chat+' => 'Incident created following a ~~',
	'Class:Incident/Attribute:origin/Value:in_person' => 'In-person~~',
	'Class:Incident/Attribute:origin/Value:in_person+' => 'Incident created following a face-to-face discussion~~',
	'Class:Incident/Attribute:origin/Value:mail' => 'E-mail',
	'Class:Incident/Attribute:origin/Value:mail+' => '',
	'Class:Incident/Attribute:origin/Value:monitoring' => 'Monitoramento',
	'Class:Incident/Attribute:origin/Value:monitoring+' => '',
	'Class:Incident/Attribute:origin/Value:phone' => 'Telefone',
	'Class:Incident/Attribute:origin/Value:phone+' => '',
	'Class:Incident/Attribute:origin/Value:portal' => 'Portal do usuário',
	'Class:Incident/Attribute:origin/Value:portal+' => '',
	'Class:Incident/Attribute:parent_change_id' => 'Mudança pai',
	'Class:Incident/Attribute:parent_change_id+' => '',
	'Class:Incident/Attribute:parent_change_ref' => 'Ref. Mudança pai',
	'Class:Incident/Attribute:parent_change_ref+' => '',
	'Class:Incident/Attribute:parent_incident_id' => 'Incidente pai',
	'Class:Incident/Attribute:parent_incident_id+' => '',
	'Class:Incident/Attribute:parent_incident_id_friendlyname' => 'parent_incident_id_friendlyname',
	'Class:Incident/Attribute:parent_incident_id_friendlyname+' => '',
	'Class:Incident/Attribute:parent_incident_ref' => 'Ref. Incidente pai',
	'Class:Incident/Attribute:parent_incident_ref+' => '',
	'Class:Incident/Attribute:parent_problem_id' => 'Problema pai',
	'Class:Incident/Attribute:parent_problem_id+' => '',
	'Class:Incident/Attribute:parent_problem_ref' => 'Ref. Problema pai',
	'Class:Incident/Attribute:parent_problem_ref+' => '',
	'Class:Incident/Attribute:pending_reason' => 'Motivo da pendência',
	'Class:Incident/Attribute:pending_reason+' => '',
	'Class:Incident/Attribute:priority' => 'Prioridade',
	'Class:Incident/Attribute:priority+' => '',
	'Class:Incident/Attribute:priority/Value:1' => 'Crítica',
	'Class:Incident/Attribute:priority/Value:1+' => '',
	'Class:Incident/Attribute:priority/Value:2' => 'Alta',
	'Class:Incident/Attribute:priority/Value:2+' => '',
	'Class:Incident/Attribute:priority/Value:3' => 'Média',
	'Class:Incident/Attribute:priority/Value:3+' => '',
	'Class:Incident/Attribute:priority/Value:4' => 'Baixa',
	'Class:Incident/Attribute:priority/Value:4+' => '',
	'Class:Incident/Attribute:public_log' => 'Log público',
	'Class:Incident/Attribute:public_log+' => '',
	'Class:Incident/Attribute:related_request_list' => 'Solicitações filhas',
	'Class:Incident/Attribute:related_request_list+' => '',
	'Class:Incident/Attribute:resolution_code' => 'Código da solução',
	'Class:Incident/Attribute:resolution_code+' => '',
	'Class:Incident/Attribute:resolution_code/Value:assistance' => 'Assistência',
	'Class:Incident/Attribute:resolution_code/Value:assistance+' => '',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed' => 'Correção de bug',
	'Class:Incident/Attribute:resolution_code/Value:bug fixed+' => '',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair' => 'Reparação de hardware',
	'Class:Incident/Attribute:resolution_code/Value:hardware repair+' => '',
	'Class:Incident/Attribute:resolution_code/Value:other' => 'Outro',
	'Class:Incident/Attribute:resolution_code/Value:other+' => '',
	'Class:Incident/Attribute:resolution_code/Value:software patch' => 'Atualização de software',
	'Class:Incident/Attribute:resolution_code/Value:software patch+' => '',
	'Class:Incident/Attribute:resolution_code/Value:system update' => 'Atualização de sistema',
	'Class:Incident/Attribute:resolution_code/Value:system update+' => '',
	'Class:Incident/Attribute:resolution_code/Value:training' => 'Treinamento',
	'Class:Incident/Attribute:resolution_code/Value:training+' => '',
	'Class:Incident/Attribute:resolution_date' => 'Data de solução',
	'Class:Incident/Attribute:resolution_date+' => '',
	'Class:Incident/Attribute:service_id' => 'Serviço',
	'Class:Incident/Attribute:service_id+' => '',
	'Class:Incident/Attribute:service_name' => 'Nome do serviço',
	'Class:Incident/Attribute:service_name+' => '',
	'Class:Incident/Attribute:servicesubcategory_id' => 'Subcategoria do serviço',
	'Class:Incident/Attribute:servicesubcategory_id+' => '',
	'Class:Incident/Attribute:servicesubcategory_name' => 'Nome da subcategoria do serviço',
	'Class:Incident/Attribute:servicesubcategory_name+' => '',
	'Class:Incident/Attribute:sla_tto_over' => 'SLA TTO ultrapassado',
	'Class:Incident/Attribute:sla_tto_over+' => 'Tempo para atribuição (TTO) do Acordo de Nível de Serviço (SLA) ultrapassado',
	'Class:Incident/Attribute:sla_tto_passed' => 'SLA TTO superado',
	'Class:Incident/Attribute:sla_tto_passed+' => 'Tempo para atribuição (TTO) do Acordo de Nível de Serviço (SLA) superado',
	'Class:Incident/Attribute:sla_ttr_over' => 'SLA TTR ultrapassado',
	'Class:Incident/Attribute:sla_ttr_over+' => 'Tempo para solução (TTR) do Acordo de Nível de Serviço (SLA) ultrapassado',
	'Class:Incident/Attribute:sla_ttr_passed' => 'SLA TTR superado',
	'Class:Incident/Attribute:sla_ttr_passed+' => 'Tempo para solução (TTR) do Acordo de Nível de Serviço (SLA) superado',
	'Class:Incident/Attribute:solution' => 'Solução',
	'Class:Incident/Attribute:solution+' => '',
	'Class:Incident/Attribute:status' => 'Status',
	'Class:Incident/Attribute:status+' => '',
	'Class:Incident/Attribute:status/Value:assigned' => 'Atribuído',
	'Class:Incident/Attribute:status/Value:assigned+' => '',
	'Class:Incident/Attribute:status/Value:closed' => 'Fechado',
	'Class:Incident/Attribute:status/Value:closed+' => '',
	'Class:Incident/Attribute:status/Value:escalated_tto' => 'TTO escalonado',
	'Class:Incident/Attribute:status/Value:escalated_tto+' => '',
	'Class:Incident/Attribute:status/Value:escalated_ttr' => 'TTR escalonado',
	'Class:Incident/Attribute:status/Value:escalated_ttr+' => '',
	'Class:Incident/Attribute:status/Value:new' => 'Novo',
	'Class:Incident/Attribute:status/Value:new+' => '',
	'Class:Incident/Attribute:status/Value:pending' => 'Pendente',
	'Class:Incident/Attribute:status/Value:pending+' => '',
	'Class:Incident/Attribute:status/Value:resolved' => 'Solucionado',
	'Class:Incident/Attribute:status/Value:resolved+' => '',
	'Class:Incident/Attribute:status/Value:waiting_for_approval' => 'Aguardando aprovação',
	'Class:Incident/Attribute:status/Value:waiting_for_approval+' => '',
	'Class:Incident/Attribute:time_spent' => 'Tempo de solução',
	'Class:Incident/Attribute:time_spent+' => '',
	'Class:Incident/Attribute:tto' => 'TTO',
	'Class:Incident/Attribute:tto+' => 'Tempo para atribuição',
	'Class:Incident/Attribute:tto_escalation_deadline' => 'Prazo determinado de atribuição (TTO)',
	'Class:Incident/Attribute:tto_escalation_deadline+' => 'Prazo determinado de Tempo para atribuição (TTO)',
	'Class:Incident/Attribute:ttr' => 'TTR',
	'Class:Incident/Attribute:ttr+' => 'Tempo para solução',
	'Class:Incident/Attribute:ttr_escalation_deadline' => 'Prazo determinado de solução (TTR)',
	'Class:Incident/Attribute:ttr_escalation_deadline+' => 'Prazo determinado de Tempo para solução (TTR)',
	'Class:Incident/Attribute:urgency' => 'Urgência',
	'Class:Incident/Attribute:urgency+' => '',
	'Class:Incident/Attribute:urgency/Value:1' => 'Crítica',
	'Class:Incident/Attribute:urgency/Value:1+' => '',
	'Class:Incident/Attribute:urgency/Value:2' => 'Alta',
	'Class:Incident/Attribute:urgency/Value:2+' => '',
	'Class:Incident/Attribute:urgency/Value:3' => 'Média',
	'Class:Incident/Attribute:urgency/Value:3+' => '',
	'Class:Incident/Attribute:urgency/Value:4' => 'Baixa',
	'Class:Incident/Attribute:urgency/Value:4+' => '',
	'Class:Incident/Attribute:user_comment' => 'Comentário do usuário',
	'Class:Incident/Attribute:user_comment+' => '',
	'Class:Incident/Attribute:user_satisfaction' => 'Satisfação do usuário',
	'Class:Incident/Attribute:user_satisfaction+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:1' => 'Muito satisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:1+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:2' => 'Satisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:2+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:3' => 'Insatisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:3+' => '',
	'Class:Incident/Attribute:user_satisfaction/Value:4' => 'Muito insatisfeito',
	'Class:Incident/Attribute:user_satisfaction/Value:4+' => '',
	'Class:Incident/Error:CannotAssignParentIncidentIdToSelf' => 'Não é possível atribuir o incidente pai ao próprio incidente',
	'Class:Incident/Method:ResolveChildTickets' => 'ResolveChildTickets (resolver solicitações filhas)',
	'Class:Incident/Method:ResolveChildTickets+' => 'Conecte a solução a solicitação filha (ev_autoresolve) e alinhe as seguintes características: serviço, equipe, agente, informação da solução',
	'Class:Incident/Stimulus:ev_assign' => 'Atribuir',
	'Class:Incident/Stimulus:ev_assign+' => '',
	'Class:Incident/Stimulus:ev_autoclose' => 'Fechado automaticamente',
	'Class:Incident/Stimulus:ev_autoclose+' => '',
	'Class:Incident/Stimulus:ev_autoresolve' => 'Solucionado automaticamente',
	'Class:Incident/Stimulus:ev_autoresolve+' => '',
	'Class:Incident/Stimulus:ev_close' => 'Fechar esta solicitação',
	'Class:Incident/Stimulus:ev_close+' => '',
	'Class:Incident/Stimulus:ev_pending' => 'Pendente',
	'Class:Incident/Stimulus:ev_pending+' => '',
	'Class:Incident/Stimulus:ev_reassign' => 'Reatribuir',
	'Class:Incident/Stimulus:ev_reassign+' => '',
	'Class:Incident/Stimulus:ev_reopen' => 'Re-abrir',
	'Class:Incident/Stimulus:ev_reopen+' => '',
	'Class:Incident/Stimulus:ev_resolve' => 'Marcar como solucionado',
	'Class:Incident/Stimulus:ev_resolve+' => '',
	'Class:Incident/Stimulus:ev_timeout' => 'Timeout',
	'Class:Incident/Stimulus:ev_timeout+' => '',
	'Menu:Incident:EscalatedIncidents' => 'Incidentes escalonados',
	'Menu:Incident:EscalatedIncidents+' => '',
	'Menu:Incident:MyIncidents' => 'Incidentes atribuídos para mim',
	'Menu:Incident:MyIncidents+' => 'Incidentes atribuídos para mim (como Agente)',
	'Menu:Incident:OpenIncidents' => 'Todos os incidentes abertos',
	'Menu:Incident:OpenIncidents+' => '',
	'Menu:Incident:Overview' => 'Visão geral',
	'Menu:Incident:Overview+' => '',
	'Menu:Incident:Shortcuts' => 'Atalhos',
	'Menu:Incident:Shortcuts+' => '',
	'Menu:IncidentManagement' => 'Gerenciamento de Incidentes',
	'Menu:IncidentManagement+' => '',
	'Menu:NewIncident' => 'Novo incidente',
	'Menu:NewIncident+' => 'Criar um novo incidente',
	'Menu:SearchIncidents' => 'Pesquisar por incidentes',
	'Menu:SearchIncidents+' => 'Pesquisar por solicitações de incidentes',
	'Tickets:Related:OpenIncidents' => 'Incidentes abertos',
	'UI-IncidentManagementOverview-IncidentByPriority-last-14-days' => 'Incidentes dos últimos 14 dias por prioridade',
	'UI-IncidentManagementOverview-Last-14-days' => 'Incidentes dos últimos 14 dias por prioridade',
	'UI-IncidentManagementOverview-OpenIncidentByAgent' => 'Incidentes abertos por agente',
	'UI-IncidentManagementOverview-OpenIncidentByCustomer' => 'Incidentes abertos por cliente',
	'UI-IncidentManagementOverview-OpenIncidentByStatus' => 'Incidentes abertos por status',
]);
